netapp_ontap.models.volume_analytics_unsupported_reason API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_analytics_unsupported_reason`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeAnalyticsUnsupportedReasonSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeAnalyticsUnsupportedReason object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `code GET`

    If file system analytics is not supported on the volume, this field provides the error code explaining why.

    Example: 111411207

  `message GET`

    If file system analytics is not supported on the volume, this field provides the error message explaining why.

    Example: File system analytics cannot be enabled on volumes that contain LUNs.